@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 #include <stdio.h>
@@ -38,13 +38,14 @@
 #include "keyboard.hh"
 #include "microdrive.hh"
 #include "spk_ay.hh"
+#include "mouse.hh"
 
 // shows the settings menu
 
 void print_copy() {
 
 	llscreen->print_string("(C) 2012 Fabio Olimpieri",-1,-1,13,0);
-	llscreen->print_string("(C) 2003-2015 Raster Software Vigo",-1,-2,13,0);
+	llscreen->print_string("(C) 2003-2016 Raster Software Vigo",-1,-2,13,0);
 }
 
 // shows the help menu
@@ -55,7 +56,7 @@ void help_menu() {
 
 	llscreen->clear_screen();
 
-	llscreen->print_string("FBZX (3.0.0)",-1,1,15,0);
+	llscreen->print_string("FBZX (3.1.0)",-1,1,15,0);
 	llscreen->print_string("Available keys",-1,2,14,0);
 	llscreen->print_string("Shift:Caps Shift        Ctrl:Symbol Shift",-1,4,11,0);
 
@@ -155,106 +156,115 @@ void settings_menu() {
 		switch(ordenador->mode128k) {
 		case 0:
 			if(ordenador->issue==2)
-				sprintf(texto,"Mode: 48K issue2");
+				sprintf(texto,"Mode: \001\01648K issue2");
 			else
-				sprintf(texto,"Mode: 48K issue3");
+				sprintf(texto,"Mode: \001\01648K issue3");
 		break;
 		case 1:
-			sprintf(texto,"Mode: Sinclair 128K");
+			sprintf(texto,"Mode: \001\016Sinclair 128K");
 		break;
 		case 2:
-			sprintf(texto,"Mode: Amstrad +2");
+			sprintf(texto,"Mode: \001\016Amstrad +2");
 		break;
 		case 3:
-			sprintf(texto,"Mode: Amstrad +2A/+3");
+			sprintf(texto,"Mode: \001\016Amstrad +2A/+3");
 		break;
 		case 4:
-			sprintf(texto,"Mode: Spanish 128K");
+			sprintf(texto,"Mode: \001\016Spanish 128K");
 		break;
 		}
   
-		llscreen->print_string(texto,-1,2,14,0);
+		llscreen->print_string(texto,-1,2,15,0);
 
 		switch(keyboard->joystick) {
 		case 0:
-			sprintf(texto,"Joystick emulation: Cursor");
+			sprintf(texto,"Joystick emulation: \001\016Cursor");
 			break;
 		case 1:
-			sprintf(texto,"Joystick emulation: Kempston");
+			sprintf(texto,"Joystick emulation: \001\016Kempston");
 			break;
 		case 2:
-			sprintf(texto,"Joystick emulation: Sinclair (1)");
+			sprintf(texto,"Joystick emulation: \001\016Sinclair (1)");
 			break;
 		case 3:
-			sprintf(texto,"Joystick emulation: Sinclair (2)");
+			sprintf(texto,"Joystick emulation: \001\016Sinclair (2)");
 			break;
 		}
-		llscreen->print_string(texto,-1,3,13,0);
+		llscreen->print_string(texto,-1,3.2,15,0);
 
 		if(spk_ay->ay_emul)
-			sprintf(texto,"AY-3-8912 Emulation: enabled");
+			sprintf(texto,"AY-3-8912 Emulation: \001\014enabled");
 		else
-			sprintf(texto,"AY-3-8912 Emulation: disabled");
+			sprintf(texto,"AY-3-8912 Emulation: \001\013disabled");
 
-		llscreen->print_string(texto,-1,4,11,0);
+		llscreen->print_string(texto,-1,4.4,15,0);
 
 		if(microdrive->mdr_active)
-			sprintf(texto,"Interface I Emulation: enabled");
+			sprintf(texto,"Interface I Emulation: \001\014enabled");
 		else
-			sprintf(texto,"Interface I Emulation: disabled");
+			sprintf(texto,"Interface I Emulation: \001\013disabled");
 
-		llscreen->print_string(texto,-1,5,15,0);
+		llscreen->print_string(texto,-1,5.6,15,0);
 
 		if(ordenador->dblscan)
-			sprintf(texto,"Double scan: enabled");
+			sprintf(texto,"Double scan: \001\014enabled");
 		else
-			sprintf(texto,"Double scan: disabled");
+			sprintf(texto,"Double scan: \001\013disabled");
 
-		llscreen->print_string(texto,-1,6,12,0);
+		llscreen->print_string(texto,-1,6.8,15,0);
 
 		if(ordenador->turbo)
-			sprintf(texto,"TURBO mode: enabled");
+			sprintf(texto,"TURBO mode: \001\014enabled");
 		else
-			sprintf(texto,"TURBO mode: disabled");
-		llscreen->print_string(texto,-1,7,14,0);
+			sprintf(texto,"TURBO mode: \001\013disabled");
+		llscreen->print_string(texto,-1,8,15,0);
 
 		if (ordenador->bw) {
-			llscreen->print_string("TV Set: \001\011B\001\012&\001\014W",-1,8,15,0);
+			llscreen->print_string("TV Set: \001\011B\001\012&\001\014W",-1,9.2,15,0);
 		} else {
-			llscreen->print_string("TV Set: \001\012C\001\014o\001\015l\001\016o\001\013r",-1,8,15,0);
+			llscreen->print_string("TV Set: \001\012C\001\014o\001\015l\001\016o\001\013r",-1,9.2,15,0);
 		}
 
-		llscreen->print_string("1: \001\01748K issue2",30,10,12,0);
+		if(mouse->enabled) {
+			sprintf(texto,"Kempston Mouse: \001\014enabled");
+		} else {
+			sprintf(texto,"Kempston Mouse: \001\013disabled");
+		}
+		llscreen->print_string(texto,-1,10.4,15,0);
 
-		llscreen->print_string("2: \001\01748K issue3",213,10,12,0);
+		llscreen->print_string("1: \001\01748K issue2",30,15,12,0);
 
-		llscreen->print_string("3: \001\017Sinclair 128K",426,10,12,0);
+		llscreen->print_string("2: \001\01748K issue3",213,15,12,0);
 
-		llscreen->print_string("4: \001\017Amstrad +2",30,12,12,0);
+		llscreen->print_string("3: \001\017Sinclair 128K",426,15,12,0);
 
-		llscreen->print_string("5: \001\017Amstrad +2A/+3",213,12,12,0);
+		llscreen->print_string("4: \001\017Amstrad +2",30,16.5,12,0);
 
-		llscreen->print_string("6: \001\017Spanish 128K",426,12,12,0);
+		llscreen->print_string("5: \001\017Amstrad +2A/+3",213,16.5,12,0);
 
-		llscreen->print_string("7: \001\017Cursor",30,14,12,0);
+		llscreen->print_string("6: \001\017Spanish 128K",426,16.5,12,0);
 
-		llscreen->print_string("8: \001\017Kempston",213,14,12,0);
+		llscreen->print_string("7: \001\017Cursor",30,18,12,0);
 
-		llscreen->print_string("9: \001\017Sinclair (1)",426,14,12,0);
+		llscreen->print_string("8: \001\017Kempston",213,18,12,0);
 
-		llscreen->print_string("0: \001\017Sinclair (2)",30,16,12,0);
+		llscreen->print_string("9: \001\017Sinclair (1)",426,18,12,0);
 
-		llscreen->print_string("I: \001\017Interface I",213,16,12,0);
+		llscreen->print_string("0: \001\017Sinclair (2)",30,19.5,12,0);
 
-		llscreen->print_string("A: \001\017AY emulation",426,16,12,0);
+		llscreen->print_string("I: \001\017Interface I",213,19.5,12,0);
 
-		llscreen->print_string("T: \001\017TURBO mode",30,18,12,0);
+		llscreen->print_string("A: \001\017AY emulation",426,19.5,12,0);
 
-		llscreen->print_string("D: \001\017Double Scan",213,18,12,0);
+		llscreen->print_string("T: \001\017TURBO mode",30,21,12,0);
 
-		llscreen->print_string("V: \001\017TV Set mode",426,18,12,0);
+		llscreen->print_string("D: \001\017Double Scan",213,21,12,0);
 
-		llscreen->print_string("ESC: \001\017return to emulator",-1,22,12,0);
+		llscreen->print_string("V: \001\017TV Set mode",426,21,12,0);
+
+		llscreen->print_string("K: \001\017Kempston Mouse",30,22.5,12,0);
+
+		llscreen->print_string("ESC: \001\017return to emulator",-1,24,12,0);
 
 		print_copy();
 
@@ -301,16 +311,17 @@ void settings_menu() {
 			ResetComputer();
 		break;
 		case SDLK_7:
-			keyboard->joystick=0;
+			keyboard->joystick=JOYSTICK_CURSOR;
 		break;
 		case SDLK_8:
-			keyboard->joystick=1;
+			keyboard->joystick=JOYSTICK_KEMPSTON;
+			mouse->enabled = false; // Kempston joystick and Kempston mouse are incompatible
 		break;
 		case SDLK_9:
-			keyboard->joystick=2;
+			keyboard->joystick=JOYSTICK_SINCLAIR1;
 		break;
 		case SDLK_0:
-			keyboard->joystick=3;
+			keyboard->joystick=JOYSTICK_SINCLAIR2;
 		break;
 		case SDLK_i:
 			if(ordenador->mode128k!=3) {
@@ -335,6 +346,16 @@ void settings_menu() {
 				ordenador->turbo = true;
 			}
 			llsound->set_speed(ordenador->turbo);
+		break;
+		case SDLK_k:
+			if(mouse->enabled) {
+				mouse->enabled = false;
+			} else {
+				mouse->enabled = true;
+				if (keyboard->joystick == JOYSTICK_KEMPSTON) {
+					keyboard->joystick = JOYSTICK_CURSOR; // Kempston joystick and Kempston mouse are incompatible
+				}
+			}
 		}
 	} while(fin);
 
