@@ -1242,6 +1242,61 @@ public:
 	}
 };
 
+class TextBlock : public TapeBlock {
+
+
+	uint8_t *data;
+	uint8_t size;
+
+public:
+
+	TextBlock() {
+		this->data = NULL;
+		this->size = 0;
+		this->has_data = false;
+	}
+	~TextBlock() {
+		if (this->data != NULL) {
+			delete[](this->data);
+		}
+	}
+
+	bool save_block(ofstream *file) {
+
+		if (this->write_8bit(file,0x30)) { // block ID
+			return true;
+		}
+		if (this->write_8bit(file, this->size)) {
+			return true;
+		}
+		file->write((char*)this->data,this->size);
+		if (this->next == NULL) {
+			return false;
+		} else {
+			return this->next->save_block(file);
+		}
+	}
+
+	bool load_block(ifstream *file) {
+
+		size_t retval;
+
+		if (this->read_8bit(file,this->size)) {
+			return true;
+		}
+		this->data = new uint8_t[this->size];
+		file->read((char*)this->data,this->size);
+		if (file->eof()) {
+			return true;
+		}
+		return false;
+	}
+
+	bool next_bit() {
+		return false;
+	}
+};
+
 Tape::Tape() {
 	this->blocks = NULL;
 	this->current_block = NULL;
@@ -1369,6 +1424,7 @@ bool Tape::load_tzx(string filename) {
 		break;
 		case 0x20: // Pause block
 			block = new PauseBlock(this);
+			printf("Pause block\n");
 		break;
 		case 0x21: // group start
 			block = new GroupStartBlock();
@@ -1382,6 +1438,9 @@ bool Tape::load_tzx(string filename) {
 		case 0x25: // Loop End
 			block = new EndLoopBlock();
 		break;
+		case 0x30: // Text block
+			block = new TextBlock();
+		break;
 		case 0x32: // Archive Info block
 			block = new InfoBlock();
 		break;
